@@ -1,18 +1,7 @@
-/**
- * Copyright (c) Istituto Nazionale di Fisica Nucleare, 2006-2014.
- *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
- *
- *     http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- */
+// SPDX-FileCopyrightText: 2006 Istituto Nazionale di Fisica Nucleare
+//
+// SPDX-License-Identifier: Apache-2.0
+
 package org.italiangrid.voms.util;
 
 import java.util.Arrays;
@@ -326,6 +315,7 @@ public class CertificateValidatorBuilder {
    * 
    * @deprecated Create a {@link CertificateValidatorBuilder} object instead.
    */
+  @Deprecated
   public static X509CertChainValidatorExt buildCertificateValidator(
     String trustAnchorsDir, ValidationErrorListener validationErrorListener,
     StoreUpdateListener storeUpdateListener, long updateInterval,
@@ -357,6 +347,7 @@ public class CertificateValidatorBuilder {
    * 
    * @deprecated Create a {@link CertificateValidatorBuilder} object instead.
    */
+  @Deprecated
   public static X509CertChainValidatorExt buildCertificateValidator(
     String trustAnchorsDir, ValidationErrorListener validationErrorListener) {
 
@@ -381,6 +372,7 @@ public class CertificateValidatorBuilder {
    * 
    * @deprecated Create a {@link CertificateValidatorBuilder} object instead.
    */
+  @Deprecated
   public static X509CertChainValidatorExt buildCertificateValidator(
     String trustAnchorsDir, ValidationErrorListener validationErrorListener,
     StoreUpdateListener storeListener) {
@@ -415,6 +407,7 @@ public class CertificateValidatorBuilder {
    * @deprecated Create a {@link CertificateValidatorBuilder} object instead.
    * 
    */
+  @Deprecated
   public static X509CertChainValidatorExt buildCertificateValidator(
     String trustAnchorsDir, ValidationErrorListener validationErrorListener,
     StoreUpdateListener storeListener, long updateInterval, boolean lazy) {
@@ -445,6 +438,7 @@ public class CertificateValidatorBuilder {
    * @deprecated Create a {@link CertificateValidatorBuilder} object instead.
    * 
    */
+  @Deprecated
   public static X509CertChainValidatorExt buildCertificateValidator(
     String trustAnchorsDir, ValidationErrorListener validationErrorListener,
     StoreUpdateListener storeListener, long updateInterval) {
@@ -475,6 +469,7 @@ public class CertificateValidatorBuilder {
    * @deprecated Create a {@link CertificateValidatorBuilder} object instead.
    * 
    */
+  @Deprecated
   public static X509CertChainValidatorExt buildCertificateValidator(
     String trustAnchorsDir, ValidationErrorListener validationErrorListener,
     long updateInterval, boolean lazy) {
@@ -502,6 +497,7 @@ public class CertificateValidatorBuilder {
    * @deprecated Create a {@link CertificateValidatorBuilder} object instead.
    * 
    */
+  @Deprecated
   public static X509CertChainValidatorExt buildCertificateValidator(
     String trustAnchorsDir, ValidationErrorListener validationErrorListener,
     long updateInterval) {
@@ -523,6 +519,7 @@ public class CertificateValidatorBuilder {
    * 
    * @deprecated Create a {@link CertificateValidatorBuilder} object instead.
    */
+  @Deprecated
   public static X509CertChainValidatorExt buildCertificateValidator(
     String trustAnchorsDir) {
 
@@ -538,6 +535,7 @@ public class CertificateValidatorBuilder {
    * 
    * @deprecated Create a {@link CertificateValidatorBuilder} object instead.
    */
+  @Deprecated
   public static X509CertChainValidatorExt buildCertificateValidator() {
 
     return buildCertificateValidator(
